# OpenHue Python SDK 1.0.0

Welcome to the OpenHue SDK documentation. This guide will help you get started with integrating and using the OpenHue SDK in your project.

## Versions

- API version: `v2`
- SDK version: `1.0.0`

## About the API

See [openhue/openhue-api](https://github.com/openhue/openhue-api)

## Table of Contents

- [Setup & Configuration](#setup--configuration)
  - [Supported Language Versions](#supported-language-versions)
  - [Installation](#installation)
- [Authentication](#authentication)
  - [API Key Authentication](#api-key-authentication)
- [Services](#services)
- [Models](#models)
- [License](#license)

# Setup & Configuration

## Supported Language Versions

This SDK is compatible with the following versions: `Python >= 3.7`

## Installation

To get started with the SDK, we recommend installing using `pip`:

```bash
pip install open-hue-sdk
```

# Authentication

## API Key Authentication

The OpenHue API uses API keys as a form of authentication. An API key is a unique identifier used to authenticate a user, developer, or a program that is calling the API.

### Setting the API key

When you initialize the SDK, you can set the API key as follows:

```py
OpenHue(
    api_key="YOUR_API_KEY",
    api_key_header="YOUR_API_KEY_HEADER"
)
```

If you need to set or update the API key after initializing the SDK, you can use:

```py
sdk.set_api_key("YOUR_API_KEY", "YOUR_API_KEY_HEADER")
```

# Services

The SDK provides various services to interact with the API.

<details> 
<summary>Below is a list of all available services with links to their detailed documentation:</summary>

| Name                                                                 |
| :------------------------------------------------------------------- |
| [AuthService](documentation/services/AuthService.md)                 |
| [ResourceService](documentation/services/ResourceService.md)         |
| [DeviceService](documentation/services/DeviceService.md)             |
| [DevicePowerService](documentation/services/DevicePowerService.md)   |
| [LightService](documentation/services/LightService.md)               |
| [LightLevelService](documentation/services/LightLevelService.md)     |
| [MotionService](documentation/services/MotionService.md)             |
| [GroupedLightService](documentation/services/GroupedLightService.md) |
| [BridgeService](documentation/services/BridgeService.md)             |
| [BridgeHomeService](documentation/services/BridgeHomeService.md)     |
| [SceneService](documentation/services/SceneService.md)               |
| [RoomService](documentation/services/RoomService.md)                 |
| [ZoneService](documentation/services/ZoneService.md)                 |
| [TemperatureService](documentation/services/TemperatureService.md)   |

</details>
<br/>

# Models

The SDK includes several models that represent the data structures used in API requests and responses. These models help in organizing and managing the data efficiently.

<details> 
<summary>Below is a list of all available models with links to their detailed documentation:</summary>

| Name                                                                                                               | Description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| :----------------------------------------------------------------------------------------------------------------- | :---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| [AuthenticateRequest](documentation/models/AuthenticateRequest.md)                                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [Response](documentation/models/Response.md)                                                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetResourcesOkResponse](documentation/models/GetResourcesOkResponse.md)                                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetDevicesOkResponse](documentation/models/GetDevicesOkResponse.md)                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetDeviceOkResponse](documentation/models/GetDeviceOkResponse.md)                                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [DevicePut](documentation/models/DevicePut.md)                                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [UpdateDeviceOkResponse](documentation/models/UpdateDeviceOkResponse.md)                                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [DeleteDeviceOkResponse](documentation/models/DeleteDeviceOkResponse.md)                                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetDevicePowersOkResponse](documentation/models/GetDevicePowersOkResponse.md)                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetDevicePowerOkResponse](documentation/models/GetDevicePowerOkResponse.md)                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetLightsOkResponse](documentation/models/GetLightsOkResponse.md)                                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetLightOkResponse](documentation/models/GetLightOkResponse.md)                                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [LightPut](documentation/models/LightPut.md)                                                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [UpdateLightOkResponse](documentation/models/UpdateLightOkResponse.md)                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetLightLevelsOkResponse](documentation/models/GetLightLevelsOkResponse.md)                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetLightLevelOkResponse](documentation/models/GetLightLevelOkResponse.md)                                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [LightLevelPut](documentation/models/LightLevelPut.md)                                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [UpdateLightLevelOkResponse](documentation/models/UpdateLightLevelOkResponse.md)                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetMotionSensorsOkResponse](documentation/models/GetMotionSensorsOkResponse.md)                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetMotionSensorOkResponse](documentation/models/GetMotionSensorOkResponse.md)                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [MotionPut](documentation/models/MotionPut.md)                                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [UpdateMotionSensorOkResponse](documentation/models/UpdateMotionSensorOkResponse.md)                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetGroupedLightsOkResponse](documentation/models/GetGroupedLightsOkResponse.md)                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetGroupedLightOkResponse](documentation/models/GetGroupedLightOkResponse.md)                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GroupedLightPut](documentation/models/GroupedLightPut.md)                                                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [UpdateGroupedLightOkResponse](documentation/models/UpdateGroupedLightOkResponse.md)                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetBridgesOkResponse](documentation/models/GetBridgesOkResponse.md)                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetBridgeOkResponse](documentation/models/GetBridgeOkResponse.md)                                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [BridgePut](documentation/models/BridgePut.md)                                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [UpdateBridgeOkResponse](documentation/models/UpdateBridgeOkResponse.md)                                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetBridgeHomesOkResponse](documentation/models/GetBridgeHomesOkResponse.md)                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetBridgeHomeOkResponse](documentation/models/GetBridgeHomeOkResponse.md)                                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetScenesOkResponse](documentation/models/GetScenesOkResponse.md)                                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ScenePost](documentation/models/ScenePost.md)                                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [CreateSceneOkResponse](documentation/models/CreateSceneOkResponse.md)                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetSceneOkResponse](documentation/models/GetSceneOkResponse.md)                                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ScenePut](documentation/models/ScenePut.md)                                                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [UpdateSceneOkResponse](documentation/models/UpdateSceneOkResponse.md)                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [DeleteSceneOkResponse](documentation/models/DeleteSceneOkResponse.md)                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetRoomsOkResponse](documentation/models/GetRoomsOkResponse.md)                                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [RoomPut](documentation/models/RoomPut.md)                                                                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [CreateRoomOkResponse](documentation/models/CreateRoomOkResponse.md)                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetRoomOkResponse](documentation/models/GetRoomOkResponse.md)                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [UpdateRoomOkResponse](documentation/models/UpdateRoomOkResponse.md)                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [DeleteRoomOkResponse](documentation/models/DeleteRoomOkResponse.md)                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetZonesOkResponse](documentation/models/GetZonesOkResponse.md)                                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [CreateZoneOkResponse](documentation/models/CreateZoneOkResponse.md)                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetZoneOkResponse](documentation/models/GetZoneOkResponse.md)                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [UpdateZoneOkResponse](documentation/models/UpdateZoneOkResponse.md)                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [DeleteZoneOkResponse](documentation/models/DeleteZoneOkResponse.md)                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetTemperaturesOkResponse](documentation/models/GetTemperaturesOkResponse.md)                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GetTemperatureOkResponse](documentation/models/GetTemperatureOkResponse.md)                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [TemperaturePut](documentation/models/TemperaturePut.md)                                                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [UpdateTemperatureOkResponse](documentation/models/UpdateTemperatureOkResponse.md)                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [Success](documentation/models/Success.md)                                                                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ResponseError](documentation/models/ResponseError.md)                                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [Error](documentation/models/Error.md)                                                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ResourceGet](documentation/models/ResourceGet.md)                                                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ResourceGetType](documentation/models/ResourceGetType.md)                                                         | Type of the supported resources                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ResourceIdentifier](documentation/models/ResourceIdentifier.md)                                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [Rtype](documentation/models/Rtype.md)                                                                             | The type of the referenced resource                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
| [DeviceGet](documentation/models/DeviceGet.md)                                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [DeviceGetType](documentation/models/DeviceGetType.md)                                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ProductData](documentation/models/ProductData.md)                                                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [DeviceGetMetadata](documentation/models/DeviceGetMetadata.md)                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [DeviceGetUsertest](documentation/models/DeviceGetUsertest.md)                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ProductArchetype](documentation/models/ProductArchetype.md)                                                       | The default archetype given by manufacturer. Can be changed by user.                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| [UsertestStatus](documentation/models/UsertestStatus.md)                                                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [DevicePutType](documentation/models/DevicePutType.md)                                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [DevicePutMetadata](documentation/models/DevicePutMetadata.md)                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [Identify](documentation/models/Identify.md)                                                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [DevicePutUsertest](documentation/models/DevicePutUsertest.md)                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [IdentifyAction](documentation/models/IdentifyAction.md)                                                           | Triggers a visual identification sequence, current implemented as (which can change in the future):<br/>Bridge performs Zigbee LED identification cycles for 5 seconds Lights perform one breathe cycle Sensors<br/>perform LED identification cycles for 15 seconds<br/>                                                                                                                                                                                                                                |
| [DevicePowerGet](documentation/models/DevicePowerGet.md)                                                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [PowerState](documentation/models/PowerState.md)                                                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [BatteryState](documentation/models/BatteryState.md)                                                               | Status of the power source of a device, only for battery powered devices.<br/><br/>- `normal` – battery level is sufficient<br/>- `low` – battery level low, some features (e.g. software update) might stop working, please change battery soon<br/>- `critical` – battery level critical, device can fail any moment<br/>                                                                                                                                                                                |
| [LightGet](documentation/models/LightGet.md)                                                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [LightGetMetadata](documentation/models/LightGetMetadata.md)                                                       | Deprecated, use metadata on device level                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| [On](documentation/models/On.md)                                                                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [LightGetDimming](documentation/models/LightGetDimming.md)                                                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [LightGetColorTemperature](documentation/models/LightGetColorTemperature.md)                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [LightGetColor](documentation/models/LightGetColor.md)                                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [LightGetDynamics](documentation/models/LightGetDynamics.md)                                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [LightGetSignaling](documentation/models/LightGetSignaling.md)                                                     | Feature containing signaling properties.                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| [LightGetMode](documentation/models/LightGetMode.md)                                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [LightGetGradient](documentation/models/LightGetGradient.md)                                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [LightGetEffects](documentation/models/LightGetEffects.md)                                                         | Basic feature containing effect properties.                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| [LightGetTimedEffects](documentation/models/LightGetTimedEffects.md)                                               | Basic feature containing timed effect properties.                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
| [LightGetPowerup](documentation/models/LightGetPowerup.md)                                                         | Feature containing properties to configure powerup behaviour of a lightsource.                                                                                                                                                                                                                                                                                                                                                                                                                        |
| [LightArchetype](documentation/models/LightArchetype.md)                                                           | Light archetype                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [MirekSchema](documentation/models/MirekSchema.md)                                                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GamutPosition](documentation/models/GamutPosition.md)                                                             | CIE XY gamut position                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
| [Gamut](documentation/models/Gamut.md)                                                                             | Color gamut of color bulb. Some bulbs do not properly return the Gamut information. In this case this is not present.                                                                                                                                                                                                                                                                                                                                                                                 |
| [GamutType](documentation/models/GamutType.md)                                                                     | The gammut types supported by hue – A Gamut of early Philips color-only products – B Limited gamut of first Hue color products – C Richer color gamut of Hue white and color ambiance products – other Color gamut of non-hue products with non-hue gamuts resp w/o gamut                                                                                                                                                                                                                             |
| [SupportedDynamicStatus](documentation/models/SupportedDynamicStatus.md)                                           | Current status of the lamp with dynamics.                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
| [SupportedSignals](documentation/models/SupportedSignals.md)                                                       | Indicates which signal is currently active.                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| [Color](documentation/models/Color.md)                                                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [SupportedGradientMode](documentation/models/SupportedGradientMode.md)                                             | Mode in which the points are currently being deployed. If not provided during PUT/POST it will be defaulted to interpolated_palette                                                                                                                                                                                                                                                                                                                                                                   |
| [SupportedEffects](documentation/models/SupportedEffects.md)                                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [SupportedTimedEffects](documentation/models/SupportedTimedEffects.md)                                             | Current status values the light is in regarding timed effects                                                                                                                                                                                                                                                                                                                                                                                                                                         |
| [PowerupPreset_1](documentation/models/PowerupPreset1.md)                                                          | When setting the custom preset the additional properties can be set. For all other presets, no other properties can be included.                                                                                                                                                                                                                                                                                                                                                                      |
| [PowerupOn_1](documentation/models/PowerupOn1.md)                                                                  |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [PowerupDimming_1](documentation/models/PowerupDimming1.md)                                                        |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [OnMode_1](documentation/models/OnMode1.md)                                                                        | State to activate after powerup.<br/>On will use the value specified in the “on” property.<br/>When setting mode “on”, the on property must be included.<br/>Toggle will alternate between on and off on each subsequent power toggle.<br/>Previous will return to the state it was in before powering off.<br/>                                                                                                                                                                                           |
| [DimmingMode_1](documentation/models/DimmingMode1.md)                                                              | Dimming will set the brightness to the specified value after power up.<br/>When setting mode “dimming”, the dimming property must be included.<br/>Previous will set brightness to the state it was in before powering off.<br/>                                                                                                                                                                                                                                                                         |
| [Dimming](documentation/models/Dimming.md)                                                                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [DimmingColor_1](documentation/models/DimmingColor1.md)                                                            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ColorMode_1](documentation/models/ColorMode1.md)                                                                  | State to activate after powerup. Availability of “color_temperature” and “color” modes depend on the capabilities of the lamp. Colortemperature will set the colortemperature to the specified value after power up. When setting color_temperature, the color_temperature property must be included Color will set the color tot he specified value after power up. When setting color mode, the color property must be included Previous will set color to the state it was in before powering off. |
| [ColorColorTemperature_1](documentation/models/ColorColorTemperature1.md)                                          |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [DimmingDelta](documentation/models/DimmingDelta.md)                                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ColorTemperature](documentation/models/ColorTemperature.md)                                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ColorTemperatureDelta](documentation/models/ColorTemperatureDelta.md)                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [Dynamics](documentation/models/Dynamics.md)                                                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [Alert](documentation/models/Alert.md)                                                                             | Joined alert control                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| [Signaling](documentation/models/Signaling.md)                                                                     | Feature containing basic signaling properties.                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| [LightPutMode](documentation/models/LightPutMode.md)                                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [Gradient](documentation/models/Gradient.md)                                                                       | Basic feature containing gradient properties.                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
| [Effects](documentation/models/Effects.md)                                                                         | Basic feature containing effect properties.                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| [LightPutTimedEffects](documentation/models/LightPutTimedEffects.md)                                               | Basic feature containing timed effect properties.                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
| [Powerup](documentation/models/Powerup.md)                                                                         | Feature containing properties to configure powerup behaviour of a lightsource.                                                                                                                                                                                                                                                                                                                                                                                                                        |
| [DimmingDeltaAction](documentation/models/DimmingDeltaAction.md)                                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ColorTemperatureDeltaAction](documentation/models/ColorTemperatureDeltaAction.md)                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [Signal](documentation/models/Signal.md)                                                                           | - `no_signal`: No signal is active. Write “no_signal” to stop active signal.<br/>- `on_off`: Toggles between max brightness and Off in fixed color.<br/>- `on_off_color`: Toggles between off and max brightness with color provided.<br/>- `alternating`: Alternates between 2 provided colors.<br/>                                                                                                                                                                                                     |
| [PowerupPreset_2](documentation/models/PowerupPreset2.md)                                                          | When setting the custom preset the additional properties can be set. For all other presets, no other properties can be included.                                                                                                                                                                                                                                                                                                                                                                      |
| [PowerupOn_2](documentation/models/PowerupOn2.md)                                                                  |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [PowerupDimming_2](documentation/models/PowerupDimming2.md)                                                        |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [OnMode_2](documentation/models/OnMode2.md)                                                                        | State to activate after powerup.<br/>On will use the value specified in the “on” property.<br/>When setting mode “on”, the on property must be included.<br/>Toggle will alternate between on and off on each subsequent power toggle.<br/>Previous will return to the state it was in before powering off.<br/>                                                                                                                                                                                           |
| [DimmingMode_2](documentation/models/DimmingMode2.md)                                                              | Dimming will set the brightness to the specified value after power up.<br/>When setting mode “dimming”, the dimming property must be included.<br/>Previous will set brightness to the state it was in before powering off.<br/>                                                                                                                                                                                                                                                                         |
| [DimmingColor_2](documentation/models/DimmingColor2.md)                                                            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ColorMode_2](documentation/models/ColorMode2.md)                                                                  | State to activate after powerup. Availability of “color_temperature” and “color” modes depend on the capabilities of the lamp. Colortemperature will set the colortemperature to the specified value after power up. When setting color_temperature, the color_temperature property must be included Color will set the color tot he specified value after power up. When setting color mode, the color property must be included Previous will set color to the state it was in before powering off. |
| [ColorColorTemperature_2](documentation/models/ColorColorTemperature2.md)                                          |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [LightLevelGet](documentation/models/LightLevelGet.md)                                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [Light](documentation/models/Light.md)                                                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [LightLevelReport](documentation/models/LightLevelReport.md)                                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [MotionGet](documentation/models/MotionGet.md)                                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [Motion](documentation/models/Motion.md)                                                                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [MotionGetSensitivity](documentation/models/MotionGetSensitivity.md)                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [MotionReport](documentation/models/MotionReport.md)                                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [SensitivityStatus](documentation/models/SensitivityStatus.md)                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [MotionPutSensitivity](documentation/models/MotionPutSensitivity.md)                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GroupedLightGet](documentation/models/GroupedLightGet.md)                                                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [GroupedLightGetAlert](documentation/models/GroupedLightGetAlert.md)                                               | Joined alert control                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| [GroupedLightGetSignaling](documentation/models/GroupedLightGetSignaling.md)                                       | Feature containing basic signaling properties.                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| [GroupedLightPutType](documentation/models/GroupedLightPutType.md)                                                 | Type of the supported resources (always `grouped_light` here)                                                                                                                                                                                                                                                                                                                                                                                                                                         |
| [Dynamics_2](documentation/models/Dynamics2.md)                                                                    |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [BridgeGet](documentation/models/BridgeGet.md)                                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [BridgeGetType](documentation/models/BridgeGetType.md)                                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [TimeZone](documentation/models/TimeZone.md)                                                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [BridgePutType](documentation/models/BridgePutType.md)                                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [BridgeHomeGet](documentation/models/BridgeHomeGet.md)                                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [BridgeHomeGetType](documentation/models/BridgeHomeGetType.md)                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [SceneGet](documentation/models/SceneGet.md)                                                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [SceneGetType](documentation/models/SceneGetType.md)                                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ActionGet](documentation/models/ActionGet.md)                                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [SceneMetadata](documentation/models/SceneMetadata.md)                                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ScenePalette](documentation/models/ScenePalette.md)                                                               | Group of colors that describe the palette of colors to be used when playing dynamics                                                                                                                                                                                                                                                                                                                                                                                                                  |
| [SceneGetStatus](documentation/models/SceneGetStatus.md)                                                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ActionGetAction](documentation/models/ActionGetAction.md)                                                         | The action to be executed on recall                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
| [ActionEffects_1](documentation/models/ActionEffects1.md)                                                          | Basic feature containing effect properties.                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| [ColorPaletteGet](documentation/models/ColorPaletteGet.md)                                                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ColorTemperaturePalettePost](documentation/models/ColorTemperaturePalettePost.md)                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ScenePaletteEffects](documentation/models/ScenePaletteEffects.md)                                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ColorTemperaturePalettePostColorTemperature](documentation/models/ColorTemperaturePalettePostColorTemperature.md) |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [Active](documentation/models/Active.md)                                                                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ScenePostType](documentation/models/ScenePostType.md)                                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ActionPost](documentation/models/ActionPost.md)                                                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ActionPostAction](documentation/models/ActionPostAction.md)                                                       | The action to be executed on recall                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
| [ActionColorTemperature](documentation/models/ActionColorTemperature.md)                                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ActionEffects_2](documentation/models/ActionEffects2.md)                                                          | Basic feature containing effect properties.                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| [ScenePutType](documentation/models/ScenePutType.md)                                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [SceneRecall](documentation/models/SceneRecall.md)                                                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [SceneRecallAction](documentation/models/SceneRecallAction.md)                                                     | When writing active, the actions in the scene are executed on the target. dynamic_palette starts dynamic scene with colors in the Palette object.                                                                                                                                                                                                                                                                                                                                                     |
| [RoomGet](documentation/models/RoomGet.md)                                                                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [RoomGetMetadata](documentation/models/RoomGetMetadata.md)                                                         | configuration object for a room                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [RoomArchetype](documentation/models/RoomArchetype.md)                                                             | Possible archetypes of a room                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
| [RoomPutMetadata](documentation/models/RoomPutMetadata.md)                                                         | configuration object for a room                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [TemperatureGet](documentation/models/TemperatureGet.md)                                                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [Temperature](documentation/models/Temperature.md)                                                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [TemperatureReport](documentation/models/TemperatureReport.md)                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [TemperaturePutType](documentation/models/TemperaturePutType.md)                                                   | Type of the supported resources (always `temperature` here)                                                                                                                                                                                                                                                                                                                                                                                                                                           |

</details>
<br/>

# License

This SDK is licensed under the MIT License.

See the [LICENSE](LICENSE) file for more details.
